# Generated by Django 3.2.11 on 2022-01-24 18:40

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aa_forum", "0003_board_discord_webhook"),
    ]

    operations = [
        migrations.AddField(
            model_name="board",
            name="use_webhook_for_replies",
            field=models.BooleanField(
                default=False,
                help_text="Use this Discord Webhook for replies as well? When activated every reply to any topic in this board will be posted to the defined Discord channel. (Child boards are excluded) Chose wisely! (Default: NO)",
            ),
        ),
    ]
