{% load i18n %}

<form id="aa-forum-form-search-{{ suffix }}" class="navbar-form" autocomplete="off" action="{% url 'aa_forum:search_results' %}" method="get">
    <div class="form-group has-feedback has-search">
        <span class="glyphicon glyphicon-search form-control-feedback"></span>
        <label style="margin: 0;">
            <input type="text" class="form-control" name="q" value="{{ search_term }}" placeholder="{% translate 'Search …' %}">
        </label>
    </div>
</form>
