{% extends "allianceauth/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Forum" %}{% endblock %}

{% block content %}
    <div class="aa-forum">
        <div class="aa-forum-header">
            {% block aa_forum_header %}{% endblock %}
        </div>

        <div class="aa-forum-body">
            {% block aa_forum_body %}{% endblock %}
        </div>

        <div class="aa-forum-svg-wrapper">
            {% if NIGHT_MODE %}
                {% include "aa_forum/bundles/svg/aa-forum-icons-night-mode.svg" %}
            {% else %}
                {% include "aa_forum/bundles/svg/aa-forum-icons.svg" %}
            {% endif %}
        </div>
    </div>
{% endblock %}
