{% load bootstrap %}
{% load i18n %}
{% load aa_forum_user %}

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">
            {% translate "Reply to:" %} {{ message.sender|main_character_name }}
        </div>
    </div>

    <div class="panel-body">
        <form id="aa-forum-form-new-personal-message-reply" autocomplete="off" action="{% url 'aa_forum:personal_messages_message_reply' message.pk %}" method="post">
            <fieldset>
                {% csrf_token %}

                {{ form|bootstrap }}

                {% include "aa_forum/partials/form/required-field-hint.html" with form_horizontal=True %}

                <div class="form-group aa-forum-form-group aa-forum-form-modify-userprofile text-right clearfix">
                    <div class="col-xs-12">
                        <button class="btn btn-primary btn-sm" type="submit">
                            {% translate "Send Reply" %}
                        </button>
                    </div>
                </div>
            </fieldset>
        </form>
    </div>
</div>
