{% load aa_forum_versioned_static %}

{% if debug %}
    <script src="{% aa_forum_static 'aa_forum/javascript/aa-forum-admin.js' %}"></script>
{% else %}
    <script src="{% aa_forum_static 'aa_forum/javascript/aa-forum-admin.min.js' %}"></script>
{% endif %}
