{% extends "aa_forum/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Unread Topics » Forum" %}{% endblock %}

{% block aa_forum_header %}
    {% include "aa_forum/partials/menu.html" %}
    {% include "aa_forum/partials/forum/mark-unread-button.html" with position="above-board-list" %}

    {% translate "Unread Topics" as page_title %}
    {% include "aa_forum/partials/breadcrumb.html" with page=page_title %}
{% endblock %}

{% block aa_forum_body %}
    {% if boards %}
        {% for board in boards %}
            {% include "aa_forum/partials/forum/topic/unread-topics.html" %}
        {% endfor %}

        {% include "aa_forum/partials/forum/mark-unread-button.html" with position="below-board-list" %}
    {% else %}
        <div class="panel panel-default">
            <div class="panel-body">
                <div class="alert alert-info">
                    <p>{% translate "You have no unread topics …" %}</p>
                </div>
            </div>
        </div>
    {% endif %}
{% endblock %}


{% block extra_css %}
    {% include "aa_forum/bundles/aa-forum-css.html" %}
{% endblock %}
