{% extends "aa_forum/base.html" %}
{% load bootstrap %}

{% load static %}
{% load i18n %}

{% block page_title %}{% translate "Forum (Personal Messages » Reply)" %}{% endblock %}

{% block aa_forum_header %}
    {% include "aa_forum/partials/menu.html" %}
{% endblock %}

{% block aa_forum_body %}
    <div class="row">
        {% include "aa_forum/partials/personal-messages/sidebar.html" %}

        <div class="col-sm-8 col-md-9 col-lg-10 col-sm-pull-4 col-md-pull-3 col-lg-pull-2">
            {% include "aa_forum/partials/personal-messages/reply-message/form.html" %}
            {% include "aa_forum/partials/personal-messages/reply-message/message.html" %}
        </div>
    </div>
{% endblock %}

{% block extra_css %}
    {% include "aa_forum/bundles/aa-forum-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "aa_forum/bundles/ckeditor-js.html" %}
{% endblock %}
