{% extends "aa_forum/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Forum (Administration » Categories and Boards)" %}{% endblock %}

{% block aa_forum_header %}
    {% include "aa_forum/partials/menu.html" %}
{% endblock %}

{% block aa_forum_body %}
    <script>
        let aaForumAdminSettings = {}
    </script>

    {% include "aa_forum/partials/administration/categories.html" %}
{% endblock %}

{% block extra_css %}
    {% include "bundles/jquery-ui-css.html" %}
    {% include "aa_forum/bundles/sumoselect-css.html" %}
    {% include "aa_forum/bundles/aa-forum-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "bundles/jquery-ui-js.html" %}
    {% include "aa_forum/bundles/sumoselect-js.html" %}
    {% include "aa_forum/bundles/aa-forum-admin-js.html" %}
{% endblock %}
